redvox API documentation
Description: Provides library level metadata and constants.

# Package `redvox`

Provides library level metadata and constants.

Expand source code

    """
    Provides library level metadata and constants.
    """

    NAME: str = "redvox"
    VERSION: str = "3.0.8"

    def version() -> str:
        """Returns the version number of this library."""
        return VERSION

    def print_version() -> None:
        """Prints the version number of this library"""
        print(version())

    def print_redvox_info() -> None:
        """
        Prints information about this library to standard out.
        """
        import redvox.settings
        print()
        print(f"version: {VERSION}")
        print(f"parallelism enabled: {redvox.settings.is_parallelism_enabled()}")
        print(f"native extra enabled: {redvox.settings.is_native_extra_enabled()}")
        print(f"gui extra enabled: {redvox.settings.is_gui_extra_enabled()}")
        print(f"protobuf cpp backend enabled: {redvox.settings.is_cpp_backend_enabled()}")
        print()

## Sub-modules

`redvox.api1000`
`redvox.api900`
`redvox.cli`
`redvox.cloud`
`redvox.common`

  Top level common members and functions.

`redvox.settings`

  Provides global settings that tweak the inner workings of the SDK.

`redvox.tests`

  Tests module

## Functions

`def print_redvox_info() ‑> NoneType`

  Prints information about this library to standard out.

  Expand source code

      def print_redvox_info() -> None:
          """
          Prints information about this library to standard out.
          """
          import redvox.settings
          print()
          print(f"version: {VERSION}")
          print(f"parallelism enabled: {redvox.settings.is_parallelism_enabled()}")
          print(f"native extra enabled: {redvox.settings.is_native_extra_enabled()}")
          print(f"gui extra enabled: {redvox.settings.is_gui_extra_enabled()}")
          print(f"protobuf cpp backend enabled: {redvox.settings.is_cpp_backend_enabled()}")
          print()

`def print_version() ‑> NoneType`

  Prints the version number of this library

  Expand source code

      def print_version() -> None:
          """Prints the version number of this library"""
          print(version())

`def version() ‑> str`

  Returns the version number of this library.

  Expand source code

      def version() -> str:
          """Returns the version number of this library."""
          return VERSION